@@ -1,7 +1,10 @@
 from .base import File
 from .audio.mp3 import Mp3File
 from .documents.html import HtmlFile
+from .documents.markdown import MarkdownFile
+from .images.gif import GifFile
 from .images.jpeg import JpegFile
+from .images.png import PngFile
 from .video.mkv import MkvFile
 from .video.mp4 import Mp4File
 from .video.webm import WebmFile
